/***********************************************************************\
|    Project:           Digitalization & worker-level wage effects		|
|    Author:        	S. Genz, F. Lehmer, M. Janser				 	|
|    Date:           	2018-05-22	                                   	|
|    Purpose:        	Descriptive Tables of sample means 				|
|    		        	Updated version for resub		 				|
|    Do-file version:   v4	 		                                   	|
|                                                                      	|
|    Content		                                                   	|
|    --------------------                                              	|
|    - 		                                                          	|
|                                                                      	|
|    List of changes                                                   	|
|    --------------------                                              	|
|	 - weights for table 3 used											|
| 	 - additional variables: est size categories, 4 bula aggregates,	|
|	   wz08_2 Steller 10 most important categories						|
|																		|
|																		|
|	 To Do List:														|
|	 - 																	|
| 	 - 																	|
|                                                                      	|
\***********************************************************************/ 
version 14
clear
set 				more off 
capture 			log close

*------------------------------------------------------------------------------*
*	Path Definition 
*------------------------------------------------------------------------------*

local user = 2								// 1 -> L: ; 2 -> N:

if `user' == 1 {
	global 				main 		"L:\Ablagen\D01700-FG-BAM\!Projekte\Arbeitenviernull\DigiWages"
}		
else if `user' == 2 {
	global 				main 		"N:\Ablagen\D01700-FG-BAM\!Projekte\Arbeitenviernull\DigiWages"
}
	global 				orig 		"${main}\data-orig"
	global 				temp		"${main}\data-temp"
	global 				intermed	"${main}\data-intermed"
	global 				log			"${main}\log"	
	global 				results      "${main}\results"	
	global				revise		"${results}\revise"

cd ${main}		

*------------------------------------------------------------------------------*
*	Log File 
*------------------------------------------------------------------------------*
capture 			log close
log using 			"$log/explore-descriptives-resub-4.log",  replace
		
*------------------------------------------------------------------------------*
*	Data Loading and restrictions
*------------------------------------------------------------------------------*		

use $intermed/estimation-sample-2010-2016-resub,clear
count
* Only Full-time
keep if  weight==1
count
* Only balanced panel: establishment stayers in 2011 and 2016
keep if year==2011|year==2016				// Only 2011 and 2016
capture drop nsp  
sort vsnr year
by vsnr : gen nsp = _n 						
by vsnr : replace nsp = nsp[_N]
tab nsp,m
tab year
keep if nsp==2								// Only balanced: only those with 2 observations
tab year
count

sort vsnr year
cap drop wb
gen wb = bnr~=bnr[_n-1] & vsnr==vsnr[_n-1]
tab wb,m
sort vsnr wb
by vsnr: replace wb=wb[2]
drop if wb==1								// Only establishment stayers (no switchers)
drop wb
count 

*------------------------------------------------------------------------------*
*	Additional variables
*------------------------------------------------------------------------------*
* Establishment Size Categories
cap drop size
gen size=1 if estsize_c<=49
replace size=2 if estsize_c>49 & estsize_c<=499
replace size=3 if estsize_c>499
lab var size "Establishment Size Categories"
tab size,m
tab size, gen(Dsize_)

* Federal States Aggregates
cap drop agg_bula 
recode bula (1/4 = 1) (5/7 10 = 2) (8 9 = 3) (11/16 = 4) , gen(agg_bula)
tab agg_bula bula
lab var agg_bula "Aggregate Federal States of working place"
lab def agg_bula 1"1 North" 2"2 West" 3"3 South" 4"4 East"
lab values agg_bula agg_bula
tab agg_bula, gen (Dagg_bula_)

* Sector aggregates
cap drop w08_2
gen w08_2 = int(wz08/1000)
tab w08_2,m

gen ST=.  // sector-type
replace ST=1 if w08_2>=1 & w08_2<=3     // AGRICULTURE, FORESTRY AND FISHING
replace ST=2 if w08_2>=5 & w08_2<=9     // MINING AND QUARRYING
replace ST=3 if w08_2>=10 & w08_2<=33   // MANUFACTURING
replace ST=4 if w08_2==35               // ELECTRICITY, GAS, STEAM AND AIR CONDITIONING SUPPLY
replace ST=5 if w08_2>=36 & w08_2<=39   // WATER SUPPLY; SEWERAGE, WASTE MANAGEMENT AND REMEDIATION ACTIVITIES
replace ST=6 if w08_2>=41 & w08_2<=43   // CONSTRUCTION
replace ST=7 if w08_2>=45 & w08_2<=47   // WHOLESALE AND RETAIL TRADE; REPAIR OF MOTOR VEHICLES AND MOTORCYCLES
replace ST=8 if w08_2>=49 & w08_2<=53   // TRANSPORTATION AND STORAGE
replace ST=9 if w08_2>=55 & w08_2<=56   // ACCOMMODATION AND FOOD SERVICE ACTIVITIES
replace ST=10 if w08_2>=58 & w08_2<=63   // INFORMATION AND COMMUNICATION
replace ST=11 if w08_2>=64 & w08_2<=66   // FINANCIAL AND INSURANCE ACTIVITIES
replace ST=12 if w08_2==68               // REAL ESTATE ACTIVITIES
replace ST=13 if w08_2>=69 & w08_2<=75   // PROFESSIONAL, SCIENTIFIC AND TECHNICAL ACTIVITIES
replace ST=14 if w08_2>=77 & w08_2<=82   // ADMINISTRATIVE AND SUPPORT SERVICE ACTIVITIES
replace ST=15 if w08_2==84               // PUBLIC ADMINISTRATION AND DEFENCE; COMPULSORY SOCIAL SECURITY
replace ST=16 if w08_2==85               // EDUCATION
replace ST=17 if w08_2>=86 & w08_2<=88   // HUMAN HEALTH AND SOCIAL WORK ACTIVITIES 
replace ST=18 if w08_2>=90 & w08_2<=93   // ARTS, ENTERTAINMENT AND RECREATION
replace ST=19 if w08_2>=94 & w08_2<=96   // OTHER SERVICE ACTIVITIES
replace ST=20 if w08_2>=97 & w08_2<=98   // ACTIVITIES OF HOUSEHOLDS AS EMPLOYERS; U0NDIFFERENTIATED GOODS- AND SERVICES-PRODUCING ACTIVITIES OF HOUSEHOLDS FOR OWN USE
replace ST=21 if w08_2==99               // ACTIVITIES OF EXTRATERRITORIAL ORGANISATIONS AND BODIES

label define ST 1 "AGRICULTURE, FORESTRY AND FISHING" ///
2 "MINING AND QUARRYING" ///
3 "MANUFACTURING" ///
4 "ELECTRICITY, GAS, STEAM AND AIR CONDITIONING SUPPLY" ///
5 "WATER SUPPLY; SEWERAGE, WASTE MANAGEMENT AND REMEDIATION ACTIVITIES" ///
6 "CONSTRUCTION" ///
7 "WHOLESALE AND RETAIL TRADE; REPAIR OF MOTOR VEHICLES AND MOTORCYCLES" ///
8 "TRANSPORTATION AND STORAGE" ///
9 "ACCOMMODATION AND FOOD SERVICE ACTIVITIES" ///
10 "INFORMATION AND COMMUNICATION" ///
11 "FINANCIAL AND INSURANCE ACTIVITIES" ///
12 "REAL ESTATE ACTIVITIES" ///
13 "PROFESSIONAL, SCIENTIFIC AND TECHNICAL ACTIVITIES" ///
14 "ADMINISTRATIVE AND SUPPORT SERVICE ACTIVITIES" ///
15 "PUBLIC ADMINISTRATION AND DEFENCE; COMPULSORY SOCIAL SECURITY" ///
16 "EDUCATION" ///
17 "HUMAN HEALTH AND SOCIAL WORK ACTIVITIES" ///
18 "ARTS, ENTERTAINMENT AND RECREATION" ///
19 "OTHER SERVICE ACTIVITIES" ///
20 "ACTIVITIES OF HOUSEHOLDS AS EMPLOYERS" /// 
21 "ACTIVITIES OF EXTRATERRITORIAL ORGANISATIONS AND BODIES" 
label values ST ST
tab ST,m
tab ST,gen (DST_)

* Table A3


	tempvar freq
	generate byte `freq'=1
	sort w08_2
preserve 
	collapse (count) `freq' [aw=gewicht1], by(w08_2)
	gsort -`freq' w08_2
	list, sepby(`freq')
	generate rank=_n
	keep if rank<=10
	drop `freq'
	sort w08_2
	tempfile top
	save `"`top'"'
restore	
	sort w08_2
	merge w08_2 using `"`top'"'
                drop _merge

	generate top=!missing(rank)

	tab w08_2 rank
	
foreach num of numlist 10 22 25 26 27 28 29 62 84 86{	
gen Dwz`num'=0
replace Dwz`num'=1 if w08_2==`num'
}



preserve
keep if T3==0
collapse (count) `freq' [aw=gewicht1], by(w08_2)
	gsort -`freq' w08_2
	list, sepby(`freq')
restore
	

preserve
keep if T3==1
collapse (count) `freq' [aw=gewicht1], by(w08_2)
	gsort -`freq' w08_2
	list, sepby(`freq')
restore

preserve
keep if T3==2
collapse (count) `freq' [aw=gewicht1], by(w08_2)
	gsort -`freq' w08_2
	list, sepby(`freq')
restore


*------------------------------------------------------------------------------*
*	Descriptive Statistics
*------------------------------------------------------------------------------*
*** Number of individuals ***
tab year
tab year T3
tab T3 year
tab T3 year [aw=gewicht1]
*** Number of establishments ***
sort bnr year
capture drop bm
by bnr year: gen bm = _n ==1
tab bm year
tab bm T3 if year==2011
tab bm T3 if year==2016
tab bm T3 if year==2011 [aw=gewicht1]
tab bm T3 if year==2016 [aw=gewicht1]

*** Most important sectors ***

*------------------------------------------------------------------------------*
* Table: Sample means for workers 
* this is Table 4 in the paper
*------------------------------------------------------------------------------*		
global celldim T3 year
sort $celldim 

/// TO BE USED IN REVISED TABLE 3 IN Paper Page 10 : 2011 and 2016 and difference
preserve
	gen N=1
	collapse (mean) Dlevel_* Deduc_* Dsex_* age Dbefr_* Dausl gwkomp* ///
					dtox_0_3plus5 dtox_1_3plus5 dtox_2_3plus5 Dsektor* DRtyp* ///
					wdir estsize_c Dsize_* Dwz* Dagg_bula* [aw=gewicht1], fast by($celldim)
	save "${revise}\Sample-means-2011-2016-T3-fulltime-balanced-weighted.dta", replace
	export excel using "${revise}\Sample-means-2011-2016-T3-fulltime-balanced-weighted.xls", firstrow(variables) replace
restore


log close 
exit



