/***********************************************************************\
|    Project:           Digitalization & Individual-level wage effects	|
|    Author:        	Sabrina Genz, Florian Lehmer				 	|
|    Date:           	2018-04-03	                                   	|
|    Purpose:        	Wage estimation									|
| 																		| 
|    Do-file version:   v4	 		                                   	|
|                                                                      	|
|    List of changes                                                   	|
|    --------------------                                              	|
|	 - Betriebspanel added												|
| 	 - 																	|
|																		|
|	 																	|
|	 																	|
|                                                                      	|
\***********************************************************************/ 

version 14
clear all
set more off 
cap	log close
set max_memory 30g
	
*------------------------------------------------------------------------------*
*	Path Definition 
*------------------------------------------------------------------------------*
global main  = "N:\Ablagen\D01700-FG-BAM\!Projekte\Arbeitenviernull\Individuals"	// Main folder of project
global intermed	"${main}\data-intermed"		// Store original and intermed files
global temp  = "${main}\data-temp"			// Store created files 
	global graphs = "${temp}\graphs"		// Store graphs
	global xls = "${temp}\xls"				// Store Excel files
global log   = "${main}\log"				// Store logfiles
global results = "${main}\results"			//Store results
	global wages = "${results}\wages"

adopath ++ "Z:\Eigene Dateien\Syntax\Ado"			
*------------------------------------------------------------------------------*
*	Log File 
*------------------------------------------------------------------------------*
cd ${main}
global name = "C_03_Wages_resub-1"
global logname = "${log}"+"\"+"${name}"		 
log using "${logname}.log", replace		

*------------------------------------------------------------------------------*
*	Data Loading
*------------------------------------------------------------------------------*		
use "$intermed\A_02_Arbeitswelt_ind_est_2007_2016.dta",clear
*------------------------------------------------------------------------------*
*	gen wage-analysis-sample
*------------------------------------------------------------------------------*
tab year,m
tab T3 year

sort vsnr T3
by vsnr: replace T3 = T3[1]	//write T3 information for establishment of year 2011 in all spells of person
sort vsnr year
tab T3 year
/// fulltime employed only
tab weight T3 if year==2011, row
keep if  weight==1
sort bnr year
capture drop bm
by bnr year: gen bm = _n ==1
tab bm year
tab T3 year

******************************************************************************************************************************************************
* control variables for wage growth regressions:

gen ageSq = (age/10)^2 		// express age squared in 100 years to have readable coefficients in regressions
gen old  = age > 40			// dummy of "older" people
gen ageXOld = age * old 	// different age profiles for young and old workers
gen ageSqXOld = ageSq * old

gen lnpcg=ln(pcg)
gen lnpcgsq=lnpcg^2
gen lnpci=ln(pci)
gen lnpcisq=lnpci^2

// merge tools data (berufenet (Janser 2017))

rename beruf_kldb10 kldb2010_5
/*merge n:1 kldb2010_5 using "\\iab.baintern.de\DFS\017\Ablagen\D01700-Projekte\D01700-JanserM\100_Research\2017_DigiEmp\data\09_dtoagg\14_emp_dtox_2016_kldb2010_5.dta" 
tab kldb2010_5 if _merge==1
tab kldb2010_5 if _merge==2
// 151 berufe mit 12,278 obs missing
*/
cap drop skldb2010_5
gen skldb2010_5 = string(kldb2010_5)

cap drop kldb2010_3
gen kldb2010_3 = substr(skldb2010_5,1,3)

cap drop digit5
gen digit5 = substr(skldb2010_5,5,1)

gen kldb2010_3plus5 = kldb2010_3 + digit5
destring kldb2010_3plus5 kldb2010_3 digit5, replace	

// not needed any more:
cap drop skldb2010_5
cap drop kldb2010_3
cap drop digit5
cap drop jahr
tab kldb2010_3plus5,m
merge n:1 kldb2010_3plus5 using "\\iab.baintern.de\DFS\017\Ablagen\D01700-Projekte\D01700-JanserM\100_Research\2017_DigiEmp\data\09_dtoagg\15_emp_dtox_2016_kldb2010_3plus5_agg.dta" 
// check: version with all tools
// merge n:1 kldb2010_3plus5 using "\\iab.baintern.de\DFS\017\Ablagen\!Projekte\Arbeitenviernull\Arbeitswelt-4-0-IAB-ZEW-project\data-intermed\dtoxXXL_3plus5.dta" 
drop if _merge==2
drop if _merge==1
drop _merge


*******************************************************************************************************************************************************
/// fulltime-employed, balanced panel 2011 and 2016

keep if year==2011|year==2016
tab T3 year
drop if lnwdir==.
tab T3 year
capture drop nsp  
// Number of spells
sort vsnr year
by vsnr : gen nsp = _n 
by vsnr : replace nsp = nsp[_N]
tab nsp,m
tab T3 year
keep if nsp==2
tab T3 year


sort bnr year
capture drop bm
by bnr year: gen bm = _n ==1
tab bm year

sort vsnr year
gen wb = bnr~=bnr[_n-1] & vsnr==vsnr[_n-1]
tab wb if year==2016,m
sort vsnr wb
by vsnr : replace wb = wb[_N]

tab wb year,col

tab T3 year if wb==0, col
tab T3 year if wb==1, col

*------------------------------------------------------------------------------*
*	Globals
*------------------------------------------------------------------------------*		
global contreg age agesq ten tensq Dtenhi t1_d_emp lnes* dtox_1_5 dtox_2_5 // continusous regressors
global dumreg  Dausl Deduc_2-Deduc_3 Dbef_2 D1_s_bnr_2-D1_s_bnr_4 Dtask_1-Dtask_4 DST_* Dagg_bula_2-Dagg_bula_4 DRtyp_2-DRtyp_4 // dummy regressors	
global eshreg eshDlevel_2-eshDlevel_4 eshDeduc_2-eshDeduc_4 eshDsex_2 eshDausl eshgwkomp2-eshgwkomp5 ///
		eshage eshDbseg_2-eshDbseg_14 eshdtox_1_3* eshdtox_2_3*   //establishment regressors
global timereg agesq ten tensq Dtenhi lnes lnessq dtox_1_5 dtox_2_5 Dtask_1-Dtask_4 DIND_2-DIND_5 Dagg_bula_2-Dagg_bula_4 DRtyp_2-DRtyp_4		//time-varying variables
global timereg2 agesq lnes lnessq dtox_1_5 dtox_2_5 Dtask_1-Dtask_4 DIND_2-DIND_5 Dagg_bula_2-Dagg_bula_4 DRtyp_2-DRtyp_4		//time-varying variables without tenure
global bpreg pci pcg inputs //BP variables
global sec1 DST_*
global sec2 DIND_2-DIND_5
global job_hist D1_s_bnr_2-D1_s_bnr_4 t1_d_emp



global controls  old  ageSq ageXOld ageSqXOld lnes*
* additional establishment-level controls
global estcontrols eshDeduc_4 eshDausl eshDbefr_2 eshdtox_1_3plus5	eshdtox_2_3plus5 ///
					eshgwkomp1 eshgwkomp2 eshgwkomp3 eshgwkomp4 eshDsex_2 eshage lnpcg* lnpci* inputs

cap drop dy*
tabulate year, gen(dy)
drop dy1

cap drop DT3_*
tab T3, gen(DT3_)
drop DT3_1

gen DT3_2_16=DT3_2*dy2
gen DT3_3_16=DT3_3*dy2


********************************************************************************
***STAYERS***
********************************************************************************
preserve
	keep if wb==0

	iis vsnr
	tis year
	xtdes

	//// all
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 , fe vce(robust)
	estimates store all

	****************************************************************************************************************************************
	/// sex				 
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sex==1, fe vce(robust)
	estimates store sex1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sex==2, fe vce(robust)
	estimates store sex2
	*******************************************************************************************************************************

	/// age

	cap drop agecat
	gen agecat=.
	replace agecat=1 if age <30 & year==2011
	replace agecat=2 if age >=30 & age <50 & year==2011
	replace agecat=3 if age >=50 & year==2011
	tab agecat, m
	sort vsnr year
	by vsnr: replace agecat=agecat[1]
	tab agecat,m
	/// bezieht sich auf 2011:
	/// agecat=1 if alter <30
	/// agecat=2 if alter >=30 & alter <50
	/// agecat=3 if alter >=50

	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if agecat==1, fe vce(robust)
	estimates store age1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if agecat==2, fe vce(robust)
	estimates store age2
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if agecat==3, fe vce(robust)
	estimates store age3
	***************************************************************************************************************************************************
	/// qualification
	tab educ year
	by vsnr:replace educ=educ[1]
	tab educ year
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if educ==1, fe vce(robust)
	estimates store educ1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if educ==2, fe vce(robust)
	estimates store educ2
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if educ==3, fe vce(robust)
	estimates store educ3

	*******************************************************************************************************************************

	*********************************************************************************************************************************
	/// sektor
	tab sektor year
	by vsnr:replace sektor=sektor[1]
	tab sektor year
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==1, fe vce(robust)
	estimates store sektor1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==2, fe vce(robust)
	estimates store sektor2
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==3, fe vce(robust)
	estimates store sektor3
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==4, fe vce(robust)
	estimates store sektor4
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==5, fe vce(robust)
	estimates store sektor5
	*********************************************************************************************************************************
	///collect results
	/// Table 5 in the paper (the full results are contained in Table A5 in the Appendix)
	estimates table all sex1 sex2 educ1 educ2 educ3,  b(%7.4f) star stats(N r2 F)
	esttab all sex1 sex2 educ1 educ2 educ3 using "${results}\wage-growth-resub-stayer-all-sex-educ.csv",  ///
				nonumber title("Models for full sample") ///
				mtitle("all" "sex1" "sex2" "educ1" "educ2" "educ3") ///
				b(%7.4f) star(* 0.10 ** 0.05 *** 0.01) stats(N r2 F)  scsv replace
	
	/// Table 6 in the paper
	estimates table age1 age2 age3,  b(%7.4f) star stats(N r2 F)
	esttab age1 age2 age3 using "${results}\wage-growth-resub-stayer-age.csv",  ///
				nonumber title("Models for full sample") ///
				mtitle("age1" "age2" "age3") ///
				b(%7.4f) star(* 0.10 ** 0.05 *** 0.01) stats(N r2 F)  scsv replace			
	
	/// Table 8 in the paper
	estimates table sektor1 sektor2 sektor3 sektor4 sektor5, b(%7.4f) star stats(N r2 F) 
	esttab sektor1 sektor2 sektor3 sektor4 sektor5 using "${results}\wage-growth-resub-stayer-sektor.csv",  ///
				nonumber title("Models for full sample") ///
				mtitle("sektor1" "sektor2" "sektor3" "sektor4" "sektor5") ///
				b(%7.4f) star(* 0.10 ** 0.05 *** 0.01) stats(N r2 F)  scsv replace	
				
	********************************************************************************************************************************************************


	********************************************************************************************************************************************************
	/// sektor + ed

	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==1 & educ==1, fe vce(robust)
	estimates store sektor1_ed1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==1 & educ==2, fe vce(robust)
	estimates store sektor1_ed2
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==1 & educ==3, fe vce(robust)
	estimates store sektor1_ed3

	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==2 & educ==1, fe vce(robust)
	estimates store sektor2_ed1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==2 & educ==2, fe vce(robust)
	estimates store sektor2_ed2
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==2 & educ==3, fe vce(robust)
	estimates store sektor2_ed3

	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==3 & educ==1, fe vce(robust)
	estimates store sektor3_ed1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==3 & educ==2, fe vce(robust)
	estimates store sektor3_ed2
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==3 & educ==3, fe vce(robust)
	estimates store sektor3_ed3

	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==4 & educ==1, fe vce(robust)
	estimates store sektor4_ed1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==4 & educ==2, fe vce(robust)
	estimates store sektor4_ed2
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==4 & educ==3, fe vce(robust)
	estimates store sektor4_ed3

	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==5 & educ==1, fe vce(robust)
	estimates store sektor5_ed1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==5 & educ==2, fe vce(robust)
	estimates store sektor5_ed2
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls  $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==5 & educ==3, fe vce(robust)
	estimates store sektor5_ed3

	estimates table sektor1_ed1 sektor1_ed2 sektor1_ed3, b(%7.4f) star stats(N r2 F)
	estimates table sektor2_ed1 sektor2_ed2 sektor2_ed3, b(%7.4f) star stats(N r2 F) 
	estimates table sektor3_ed1 sektor3_ed2 sektor3_ed3, b(%7.4f) star stats(N r2 F)
	estimates table sektor4_ed1 sektor4_ed2 sektor4_ed3, b(%7.4f) star stats(N r2 F)
	estimates table sektor5_ed1 sektor5_ed2 sektor5_ed3, b(%7.4f) star stats(N r2 F)

	/// Table 9 in the paper
	estimates table sektor1_ed1 sektor1_ed2 sektor1_ed3 ///
				sektor2_ed1 sektor2_ed2 sektor2_ed3 ///
				sektor3_ed1 sektor3_ed2 sektor3_ed3 ///
				sektor4_ed1 sektor4_ed2 sektor4_ed3 ///
				sektor5_ed1 sektor5_ed2 sektor5_ed3, b(%7.4f) star stats(N r2 F)
	esttab sektor1_ed1 sektor1_ed2 sektor1_ed3 ///
				sektor2_ed1 sektor2_ed2 sektor2_ed3 ///
				sektor3_ed1 sektor3_ed2 sektor3_ed3 ///
				sektor4_ed1 sektor4_ed2 sektor4_ed3 ///
				sektor5_ed1 sektor5_ed2 sektor5_ed3 using "${results}\wage-growth-resub-stayer-sektor-educ.csv",  ///
				nonumber title("Models for full sample") ///
				mtitle("sektor1_ed1" "sektor1_ed2" "sektor1_ed3" "sektor2_ed1" "sektor2_ed2" "sektor2_ed3" "sektor3_ed1" /// 
				"sektor3_ed2" "sektor3_ed3" "sektor4_ed1" "sektor4_ed2" "sektor4_ed3" "sektor5_ed1" "sektor5_ed2" "sektor5_ed3") ///
				b(%7.4f) star(* 0.10 ** 0.05 *** 0.01) stats(N r2 F)  scsv replace			
				
	*********************************************************************************************************************************
	// Digital tools aggregated

	sum dtox_0_3plus5 if year==2011,d
	gen dtox_cat0=0 if year==2011
	replace dtox_cat0=1 if dtox_0_3plus5>=r(p50) & year==2011
	replace dtox_cat0=2 if dtox_0_3plus5>=r(p75) & year==2011
	tab dtox_cat0 if year==2011,m
	by vsnr: replace dtox_cat0 = dtox_cat0[1]
	sum dtox_0_3plus5 if dtox_cat0==0
	sum dtox_0_3plus5 if dtox_cat0==1
	sum dtox_0_3plus5 if dtox_cat0==2
	tab dtox_cat0 year


	// 3.0 tools
	sum dtox_1_3plus5 if year==2011,d
	gen dtox_cat1=0 if year==2011
	replace dtox_cat1=1 if dtox_1_3plus5>=r(p50)  & year==2011
	replace dtox_cat1=2 if dtox_1_3plus5>=r(p75)  & year==2011
	tab dtox_cat1  if year==2011,m
	by vsnr: replace dtox_cat1 = dtox_cat1[1]
	sum dtox_1_3plus5 if dtox_cat1==0
	sum dtox_1_3plus5 if dtox_cat1==1
	sum dtox_1_3plus5 if dtox_cat1==2
	tab dtox_cat1 year


	// 4.0 tools
	sum dtox_2_3plus5 if year==2011,d
	gen dtox_cat2=0 if year==2011
	replace dtox_cat2=1 if dtox_2_3plus5>=r(p50) & year==2011
	replace dtox_cat2=2 if dtox_2_3plus5>=r(p75) & year==2011
	tab dtox_cat2 if year==2011,m
	by vsnr: replace dtox_cat2 = dtox_cat2[1]
	sum dtox_2_3plus5 if dtox_cat2==0
	sum dtox_2_3plus5 if dtox_cat2==1
	sum dtox_2_3plus5 if dtox_cat2==2
	tab dtox_cat2 year


	********************************************************************************************************************************
	/// tools
	/// cat1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if dtox_cat1==0, fe vce(robust)
	estimates store tools1_0
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if dtox_cat1==1, fe vce(robust)
	estimates store tools1_1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if dtox_cat1==2, fe vce(robust)
	estimates store tools1_2

	estimates table tools1_0 tools1_1 tools1_2 , b(%7.4f) star stats(N r2 F)
				
	/// cat2
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if dtox_cat2==0, fe vce(robust)
	estimates store tools2_0
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if dtox_cat2==1, fe vce(robust)
	estimates store tools2_1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if dtox_cat2==2, fe vce(robust)
	estimates store tools2_2

	
	/// Table 7 in the paper
	estimates table tools2_0 tools2_1 tools2_2 , b(%7.4f) star stats(N r2 F)	
	estimates table tools1_0 tools1_1 tools1_2 tools2_0 tools2_1 tools2_2 , b(%7.4f) star stats(N r2 F)
	esttab tools1_0 tools1_1 tools1_2 tools2_0 tools2_1 tools2_2 using "${results}\wage-growth-resub-stayer-tools.csv",  ///
				nonumber title("Models for full sample") ///
				mtitle("tools1_0" "tools1_1" "tools1_2" "tools2_0" "tools2_1" "tools2_2") ///
				b(%7.4f) star(* 0.10 ** 0.05 *** 0.01) stats(N r2 F)  scsv replace	

	/// sektor & tools

	tab dtox_cat2 year if sektor==1 
	tab dtox_cat2 year if sektor==2
	tab dtox_cat2 year if sektor==3 
	tab dtox_cat2 year if sektor==4 
	tab dtox_cat2 year if sektor==5 

	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==1 & dtox_cat2==0, fe vce(robust)
	estimates store sektor1_tools2_0
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==1 & dtox_cat2==1, fe vce(robust)
	estimates store sektor1_tools2_1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==1 & dtox_cat2==2, fe vce(robust)
	estimates store sektor1_tools2_2


	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==2 & dtox_cat2==0, fe vce(robust)
	estimates store sektor2_tools2_0
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==2 & dtox_cat2==1, fe vce(robust)
	estimates store sektor2_tools2_1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==2 & dtox_cat2==2, fe vce(robust)
	estimates store sektor2_tools2_2

	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==3 & dtox_cat2==0, fe vce(robust)
	estimates store sektor3_tools2_0
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==3 & dtox_cat2==1, fe vce(robust)
	estimates store sektor3_tools2_1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==3 & dtox_cat2==2, fe vce(robust)
	estimates store sektor3_tools2_2

	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==4 & dtox_cat2==0, fe vce(robust)
	estimates store sektor4_tools2_0
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==4 & dtox_cat2==1, fe vce(robust)
	estimates store sektor4_tools2_1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==4 & dtox_cat2==2, fe vce(robust)
	estimates store sektor4_tools2_2

	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==5 & dtox_cat2==0, fe vce(robust)
	estimates store sektor5_tools2_0
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==5 & dtox_cat2==1, fe vce(robust)
	estimates store sektor5_tools2_1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==5 & dtox_cat2==2, fe vce(robust)
	estimates store sektor5_tools2_2



	/// Table 10 in the paper
	estimates table sektor1_tools2_0 sektor1_tools2_1 sektor1_tools2_2, b(%7.4f) star stats(N r2 F)
	estout  sektor1_tools2_0 sektor1_tools2_1 sektor1_tools2_2 using $results/wage-growth-sektor-1-tools2.txt , cells(b(star fmt(4)) /// 
				se(par fmt(4)))  starlevels( * 0.10 ** 0.05 *** 0.010) stats(N r2 F) replace
	estimates table sektor2_tools2_0 sektor2_tools2_1 sektor2_tools2_2, b(%7.4f) star stats(N r2 F)
	estout  sektor2_tools2_0 sektor2_tools2_1 sektor2_tools2_2 using $results/wage-growth-sektor-2-tools2.txt , cells(b(star fmt(4)) /// 
				se(par fmt(4)))  starlevels( * 0.10 ** 0.05 *** 0.010) stats(N r2 F) replace
	estimates table sektor3_tools2_0 sektor3_tools2_1 sektor3_tools2_2, b(%7.4f) star stats(N r2 F) 
	estout  sektor3_tools2_0 sektor3_tools2_1 sektor3_tools2_2 using $results/wage-growth-sektor-3-tools2.txt , cells(b(star fmt(4)) /// 
				se(par fmt(4)))  starlevels( * 0.10 ** 0.05 *** 0.010) stats(N r2 F) replace
	estimates table sektor4_tools2_0 sektor4_tools2_1 sektor4_tools2_2, b(%7.4f) star stats(N r2 F)
	estout  sektor4_tools2_0 sektor4_tools2_1 sektor4_tools2_2 using $results/wage-growth-sektor-4-tools2.txt , cells(b(star fmt(4)) /// 
				se(par fmt(4)))  starlevels( * 0.10 ** 0.05 *** 0.010) stats(N r2 F) replace
	estimates table sektor5_tools2_0 sektor5_tools2_1 sektor5_tools2_2, b(%7.4f) star stats(N r2 F)
	estout  sektor5_tools2_0 sektor5_tools2_1 sektor5_tools2_2 using $results/wage-growth-sektor-1-tools2.txt , cells(b(star fmt(4)) /// 
				se(par fmt(4)))  starlevels( * 0.10 ** 0.05 *** 0.010) stats(N r2 F) replace
				
	esttab sektor1_tools2_0 sektor1_tools2_1 sektor1_tools2_2 sektor2_tools2_0 sektor2_tools2_1 sektor2_tools2_2 ///
				sektor3_tools2_0 sektor3_tools2_1 sektor3_tools2_2 sektor4_tools2_0 sektor4_tools2_1 sektor4_tools2_2 /// 
				sektor5_tools2_0 sektor5_tools2_1 sektor5_tools2_2 using "${results}\wage-growth-resub-stayer-sektor-tools.csv",  ///
				nonumber title("Models for full sample") ///
				mtitle("s1_tools1_0" "s1_tools1_1" "s1_tools1_2" "s2_tools1_0" "s2_tools1_1" "s2_tools1_2" /// 
				"s3_tools1_0" "s3_tools1_1" "s3_tools1_2" "s4_tools1_0" "s4_tools1_1" "s4_tools1_2" "s5_tools1_0" "s5_tools1_1" "s5_tools1_2") ///
				b(%7.4f) star(* 0.10 ** 0.05 *** 0.01) stats(N r2 F)  scsv replace	
	
	*********************************************************************************************************************************

	/// tasks
	tab haupttask,m
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols dtox_0_3plus5 if haupttask==1, fe vce(robust)
	estimates store tasks1
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols dtox_0_3plus5 if haupttask==2, fe vce(robust)
	estimates store tasks2
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols dtox_0_3plus5 if haupttask==3, fe vce(robust)
	estimates store tasks3
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols dtox_0_3plus5 if haupttask==4, fe vce(robust)
	estimates store tasks4
	xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols dtox_0_3plus5 if haupttask==5, fe vce(robust)
	estimates store tasks5
	
	/// Table A6 in the paper
	estimates table tasks1 tasks2 tasks3 tasks4 tasks5 , star stats(N r2 F)
	estout  tasks1 tasks2 tasks3 tasks4 tasks5 using $results/wage-growth-tasks.txt, cells(b(star fmt(4)) se(par fmt(4))) ///
				starlevels( * 0.10 ** 0.05 *** 0.010) stats(N r2 F) replace
				
	***********************************************************************************************
				
restore




********************************************************************************
***Robustness Checks***
********************************************************************************
********************************************************************************
***STAYERS and LEAVERS***
********************************************************************************

		

		iis vsnr
		tis year
		xtdes

		//// all
		xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 , fe vce(robust)
		estimates store all

		****************************************************************************************************************************************
		/// sex				 
		xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sex==1, fe vce(robust)
		estimates store sex1
		xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sex==2, fe vce(robust)
		estimates store sex2
		*******************************************************************************************************************************

		/// age

		cap drop agecat
		gen agecat=.
		replace agecat=1 if age <30 & year==2011
		replace agecat=2 if age >=30 & age <50 & year==2011
		replace agecat=3 if age >=50 & year==2011
		tab agecat, m
		sort vsnr year
		by vsnr: replace agecat=agecat[1]
		tab agecat,m
		/// bezieht sich auf 2011:
		/// agecat=1 if alter <30
		/// agecat=2 if alter >=30 & alter <50
		/// agecat=3 if alter >=50

		xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if agecat==1, fe vce(robust)
		estimates store age1
		xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if agecat==2, fe vce(robust)
		estimates store age2
		xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if agecat==3, fe vce(robust)
		estimates store age3
		***************************************************************************************************************************************************
		/// qualification
		tab educ year
		by vsnr:replace educ=educ[1]
		tab educ year
		xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if educ==1, fe vce(robust)
		estimates store educ1
		xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if educ==2, fe vce(robust)
		estimates store educ2
		xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if educ==3, fe vce(robust)
		estimates store educ3

		*******************************************************************************************************************************

		*********************************************************************************************************************************
		/// sektor
		tab sektor year
		by vsnr:replace sektor=sektor[1]
		tab sektor year
		xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==1, fe vce(robust)
		estimates store sektor1
		xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==2, fe vce(robust)
		estimates store sektor2
		xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==3, fe vce(robust)
		estimates store sektor3
		xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==4, fe vce(robust)
		estimates store sektor4
		xi: xtreg  lnwdir DT3_2_16 DT3_3_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5  if sektor==5, fe vce(robust)
		estimates store sektor5
		*********************************************************************************************************************************
		///collect results
		/// Table A7 in the paper
		estimates table all sex1 sex2 educ1 educ2 educ3,  b(%7.4f) star stats(N r2 F)
		esttab all sex1 sex2 educ1 educ2 educ3 using "${results}\wage-growth-resub-all-all-sex-educ.csv",  ///
					nonumber title("Models for full sample") ///
					mtitle("all" "sex1" "sex2" "educ1" "educ2" "educ3") ///
					b(%7.4f) star(* 0.10 ** 0.05 *** 0.01) stats(N r2 F)  scsv replace
					

					
					
*********************************************************************************************************************************************
***Further Robustness Checks not included as Tables in the paper but available on request***
**********************************************************************************************************************************************
					
					
					
				
		estimates table age1 age2 age3,  b(%7.4f) star stats(N r2 F)
		esttab age1 age2 age3 using "${results}\wage-growth-resub-all-age.csv",  ///
					nonumber title("Models for full sample") ///
					mtitle("age1" "age2" "age3") ///
					b(%7.4f) star(* 0.10 ** 0.05 *** 0.01) stats(N r2 F)  scsv replace							
		estimates table sektor1 sektor2 sektor3 sektor4 sektor5, b(%7.4f) star stats(N r2 F) 
		esttab sektor1 sektor2 sektor3 sektor4 sektor5 using "${results}\wage-growth-resub-all-sektor.csv",  ///
					nonumber title("Models for full sample") ///
					mtitle("sektor1" "sektor2" "sektor3" "sektor4" "sektor5") ///
					b(%7.4f) star(* 0.10 ** 0.05 *** 0.01) stats(N r2 F)  scsv replace	
		********************************************************************************************************************************************************
		

****************************************************************************************************************************************
			
//// wage growth within treatment firms			
			
keep if wb==0
		
preserve
	tab T3
	keep if T3==2
	tab educ year,m
	recode educ (0 1 =1) (2 = 2) (3 = 3), gen(neduc)
	tab educ neduc
	by vsnr:replace neduc=neduc[1]
	tab neduc, gen(Dneduc_)
	gen Dneduc_1_16=Dneduc_1*dy2
	gen Dneduc_2_16=Dneduc_2*dy2
	gen Dneduc_3_16=Dneduc_3*dy2
	
	xi: xtreg  lnwdir Dneduc_2_16 Dneduc_3_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5, fe vce(robust)
	estimates store Treat_educ
	
	by vsnr:replace sektor=sektor[1]
	
	xi: xtreg  lnwdir Dneduc_2_16 Dneduc_3_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==1, fe vce(robust)
	estimates store Treat_educ_s1
	xi: xtreg  lnwdir Dneduc_2_16 Dneduc_3_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==2, fe vce(robust)
	estimates store Treat_educ_s2
	xi: xtreg  lnwdir Dneduc_2_16 Dneduc_3_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==3, fe vce(robust)
	estimates store Treat_educ_s3
	xi: xtreg  lnwdir Dneduc_2_16 Dneduc_3_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==4, fe vce(robust)
	estimates store Treat_educ_s4
	xi: xtreg  lnwdir Dneduc_2_16 Dneduc_3_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==5, fe vce(robust)
	estimates store Treat_educ_s5
	estimates table Treat_educ Treat_educ_s1 Treat_educ_s2 Treat_educ_s3 Treat_educ_s4 Treat_educ_s5,  b(%7.4f) star stats(N r2 F)

	// Digital tools aggregated

	sum dtox_0_3plus5 if year==2011,d
	gen dtox_cat0=0 if year==2011
	replace dtox_cat0=1 if dtox_0_3plus5>=r(p50) & year==2011
	replace dtox_cat0=2 if dtox_0_3plus5>=r(p75) & year==2011
	tab dtox_cat0 if year==2011,m
	by vsnr: replace dtox_cat0 = dtox_cat0[1]
	sum dtox_0_3plus5 if dtox_cat0==0
	sum dtox_0_3plus5 if dtox_cat0==1
	sum dtox_0_3plus5 if dtox_cat0==2
	tab dtox_cat0 year


	// 3.0 tools
	sum dtox_1_3plus5 if year==2011,d
	gen dtox_cat1=0 if year==2011
	replace dtox_cat1=1 if dtox_1_3plus5>=r(p50)  & year==2011
	replace dtox_cat1=2 if dtox_1_3plus5>=r(p75)  & year==2011
	tab dtox_cat1  if year==2011,m
	by vsnr: replace dtox_cat1 = dtox_cat1[1]
	sum dtox_1_3plus5 if dtox_cat1==0
	sum dtox_1_3plus5 if dtox_cat1==1
	sum dtox_1_3plus5 if dtox_cat1==2
	tab dtox_cat1 year


	// 4.0 tools
	sum dtox_2_3plus5 if year==2011,d
	gen dtox_cat2=0 if year==2011
	replace dtox_cat2=1 if dtox_2_3plus5>=r(p50) & year==2011
	replace dtox_cat2=2 if dtox_2_3plus5>=r(p75) & year==2011
	tab dtox_cat2 if year==2011,m
	by vsnr: replace dtox_cat2 = dtox_cat2[1]
	sum dtox_2_3plus5 if dtox_cat2==0
	sum dtox_2_3plus5 if dtox_cat2==1
	sum dtox_2_3plus5 if dtox_cat2==2
	tab dtox_cat2 year

	
	tab dtox_cat1, gen(Ddtox1_)
	tab dtox_cat2, gen(Ddtox2_)

	gen Ddtox1_1_16=Ddtox1_2*dy2
	gen Ddtox1_2_16=Ddtox1_3*dy2
	gen Ddtox2_1_16=Ddtox2_2*dy2
	gen Ddtox2_2_16=Ddtox2_3*dy2
	xi: xtreg  lnwdir  Ddtox1_1_16 Ddtox1_2_16 Ddtox2_1_16 Ddtox2_2_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm , fe vce(robust)
	estimates store Treat_dtox2
	
	xi: xtreg  lnwdir  Ddtox1_1_16 Ddtox1_2_16 Ddtox2_1_16 Ddtox2_2_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm  if sektor==1, fe vce(robust)
	estimates store Treat_dtox2_S1
	xi: xtreg  lnwdir  Ddtox1_1_16 Ddtox1_2_16 Ddtox2_1_16 Ddtox2_2_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm  if sektor==2, fe vce(robust)
	estimates store Treat_dtox2_S2
	xi: xtreg  lnwdir  Ddtox1_1_16 Ddtox1_2_16 Ddtox2_1_16 Ddtox2_2_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm  if sektor==3, fe vce(robust)
	estimates store Treat_dtox2_S3
	xi: xtreg  lnwdir  Ddtox1_1_16 Ddtox1_2_16 Ddtox2_1_16 Ddtox2_2_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm  if sektor==4, fe vce(robust)
	estimates store Treat_dtox2_S4
	xi: xtreg  lnwdir  Ddtox1_1_16 Ddtox1_2_16 Ddtox2_1_16 Ddtox2_2_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm  if sektor==5, fe vce(robust)
	estimates store Treat_dtox2_S5
	estimates table Treat_dtox2 Treat_dtox2_S1 Treat_dtox2_S2 Treat_dtox2_S3 Treat_dtox2_S4 Treat_dtox2_S5, b(%7.4f) star stats(N r2 F) 
	
restore


//// wage growth within laterunner firms

preserve
	tab T3
	keep if T3==0
	tab educ year,m
	recode educ (0 1 =1) (2 = 2) (3 = 3), gen(neduc)
	tab educ neduc
	by vsnr:replace neduc=neduc[1]
	tab neduc, gen(Dneduc_)
	gen Dneduc_1_16=Dneduc_1*dy2
	gen Dneduc_2_16=Dneduc_2*dy2
	gen Dneduc_3_16=Dneduc_3*dy2
	
	xi: xtreg  lnwdir Dneduc_2_16 Dneduc_3_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5, fe vce(robust)
	estimates store Late_educ
	
	by vsnr:replace sektor=sektor[1]
	
	xi: xtreg  lnwdir Dneduc_2_16 Dneduc_3_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==1, fe vce(robust)
	estimates store Late_educ_s1
	xi: xtreg  lnwdir Dneduc_2_16 Dneduc_3_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==2, fe vce(robust)
	estimates store Late_educ_s2
	xi: xtreg  lnwdir Dneduc_2_16 Dneduc_3_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==3, fe vce(robust)
	estimates store Late_educ_s3
	xi: xtreg  lnwdir Dneduc_2_16 Dneduc_3_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==4, fe vce(robust)
	estimates store Late_educ_s4
	xi: xtreg  lnwdir Dneduc_2_16 Dneduc_3_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==5, fe vce(robust)
	estimates store Late_educ_s5
	estimates table Late_educ Late_educ_s1 Late_educ_s2 Late_educ_s3 Late_educ_s4 Late_educ_s5,  b(%7.4f) star stats(N r2 F)

	// Digital tools aggregated

	sum dtox_0_3plus5 if year==2011,d
	gen dtox_cat0=0 if year==2011
	replace dtox_cat0=1 if dtox_0_3plus5>=r(p50) & year==2011
	replace dtox_cat0=2 if dtox_0_3plus5>=r(p75) & year==2011
	tab dtox_cat0 if year==2011,m
	by vsnr: replace dtox_cat0 = dtox_cat0[1]
	sum dtox_0_3plus5 if dtox_cat0==0
	sum dtox_0_3plus5 if dtox_cat0==1
	sum dtox_0_3plus5 if dtox_cat0==2
	tab dtox_cat0 year


	// 3.0 tools
	sum dtox_1_3plus5 if year==2011,d
	gen dtox_cat1=0 if year==2011
	replace dtox_cat1=1 if dtox_1_3plus5>=r(p50)  & year==2011
	replace dtox_cat1=2 if dtox_1_3plus5>=r(p75)  & year==2011
	tab dtox_cat1  if year==2011,m
	by vsnr: replace dtox_cat1 = dtox_cat1[1]
	sum dtox_1_3plus5 if dtox_cat1==0
	sum dtox_1_3plus5 if dtox_cat1==1
	sum dtox_1_3plus5 if dtox_cat1==2
	tab dtox_cat1 year


	// 4.0 tools
	sum dtox_2_3plus5 if year==2011,d
	gen dtox_cat2=0 if year==2011
	replace dtox_cat2=1 if dtox_2_3plus5>=r(p50) & year==2011
	replace dtox_cat2=2 if dtox_2_3plus5>=r(p75) & year==2011
	tab dtox_cat2 if year==2011,m
	by vsnr: replace dtox_cat2 = dtox_cat2[1]
	sum dtox_2_3plus5 if dtox_cat2==0
	sum dtox_2_3plus5 if dtox_cat2==1
	sum dtox_2_3plus5 if dtox_cat2==2
	tab dtox_cat2 year

	tab dtox_cat1, gen(Ddtox1_)
	tab dtox_cat2, gen(Ddtox2_)

	gen Ddtox1_1_16=Ddtox1_1*dy2
	gen Ddtox1_2_16=Ddtox1_2*dy2
	gen Ddtox2_1_16=Ddtox2_1*dy2
	gen Ddtox2_2_16=Ddtox2_2*dy2
	xi: xtreg  lnwdir Ddtox1_1_16 Ddtox1_2_16 Ddtox2_1_16 Ddtox2_2_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5, fe vce(robust)
	estimates store Late_dtox2
	
	xi: xtreg  lnwdir Ddtox1_1_16 Ddtox1_2_16 Ddtox2_1_16 Ddtox2_2_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==1, fe vce(robust)
	estimates store Late_dtox2_S1
	xi: xtreg  lnwdir Ddtox1_1_16 Ddtox1_2_16 Ddtox2_1_16 Ddtox2_2_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==2, fe vce(robust)
	estimates store Late_dtox2_S2
	xi: xtreg  lnwdir Ddtox1_1_16 Ddtox1_2_16 Ddtox2_1_16 Ddtox2_2_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==3, fe vce(robust)
	estimates store Late_dtox2_S3
	xi: xtreg  lnwdir Ddtox1_1_16 Ddtox1_2_16 Ddtox2_1_16 Ddtox2_2_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==4, fe vce(robust)
	estimates store Late_dtox2_S4
	xi: xtreg  lnwdir Ddtox1_1_16 Ddtox1_2_16 Ddtox2_1_16 Ddtox2_2_16  dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==5, fe vce(robust)
	estimates store Late_dtox2_S5
	estimates table Late_dtox2 Late_dtox2_S1 Late_dtox2_S2 Late_dtox2_S3 Late_dtox2_S4 Late_dtox2_S5, b(%7.4f) star stats(N r2 F)
	
					
	gen Dtask_1_16=Dtask_1*dy2
	gen Dtask_2_16=Dtask_2*dy2
	gen Dtask_3_16=Dtask_3*dy2
	gen Dtask_5_16=Dtask_5*dy2
	xi: xtreg  lnwdir Dtask_1_16 Dtask_2_16 Dtask_3_16 Dtask_5_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5, fe vce(robust)
	estimates store Late_tasks
	xi: xtreg  lnwdir Dtask_1_16 Dtask_2_16 Dtask_3_16 Dtask_5_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==1, fe vce(robust)
	estimates store Late_tasks_S1
	xi: xtreg  lnwdir Dtask_1_16 Dtask_2_16 Dtask_3_16 Dtask_5_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==2, fe vce(robust)
	estimates store Late_tasks_S2
	xi: xtreg  lnwdir Dtask_1_16 Dtask_2_16 Dtask_3_16 Dtask_5_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==3, fe vce(robust)
	estimates store Late_tasks_S3
	xi: xtreg  lnwdir Dtask_1_16 Dtask_2_16 Dtask_3_16 Dtask_5_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==4, fe vce(robust)
	estimates store Late_tasks_S4
	xi: xtreg  lnwdir Dtask_1_16 Dtask_2_16 Dtask_3_16 Dtask_5_16 dy*  $controls $estcontrols sh_ana sh_ina sh_rc sh_rm dtox_1_5 dtox_2_5 if sektor==5, fe vce(robust)
	estimates store Late_tasks_S5
	estimates table Late_tasks Late_tasks_S1 Late_tasks_S2 Late_tasks_S3 Late_tasks_S4 Late_tasks_S5, b(%7.4f) star stats(N r2 F)
	
restore



* Treatment: T3 Pioneer vs Latecomer
*------------------------------------------------------------------------------*
* Base
preserve
	keep if wb==0
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy*, fe vce(robust)
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg, fe vce(robust)
	estimates store base

	* Establishment controlls
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg $eshreg, fe vce(robust)
	estimates store base_est

	* Establishment controlls without tenure
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg, fe vce(robust)
	estimates store base_ot_est

	* Establishment controlls without tenure + bp
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg, fe vce(robust)
	estimates store base_ot_est_bp


	estimates table base  base_est base_ot_est ///
					base_ot_est_bp,  b(%7.4f) star stats(N r2 F)
	esttab base base_est base_ot_est  ///
			base_ot_est_bp using "${results}\wage-growth-resub-stayer.csv",  ///
			nonumber title("Models for full sample") ///
			mtitle("all" "all_est" "all_ot_est" ///
			 "all__ot_est_bp") ///
			star(* 0.10 ** 0.05 *** 0.01) stats(N r2 F)  scsv replace

restore


preserve
	keep if wb==1
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy*, fe vce(robust)
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg, fe vce(robust)
	estimates store base

	* Establishment controlls
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg $eshreg, fe vce(robust)
	estimates store base_est

	* Establishment controlls without tenure
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg, fe vce(robust)
	estimates store base_ot_est

	* Establishment controlls without tenure + bp
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg, fe vce(robust)
	estimates store base_ot_est_bp


	estimates table base  base_est base_ot_est ///
					base_ot_est_bp,  b(%7.4f) star stats(N r2 F)
	esttab base base_est base_ot_est  ///
			base_ot_est_bp using "${results}\wage-growth-resub-mover.csv",  ///
			nonumber title("Models for full sample") ///
			mtitle("all" "all_est" "all_ot_est" ///
			 "all__ot_est_bp") ///
			star(* 0.10 ** 0.05 *** 0.01) stats(N r2 F)  scsv replace
restore


	xtreg  lnwdir DT3_2_16 DT3_3_16 dy*, fe vce(robust)
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg, fe vce(robust)
	estimates store base

	* Establishment controlls
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg $eshreg, fe vce(robust)
	estimates store base_est

	* Establishment controlls without tenure
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg, fe vce(robust)
	estimates store base_ot_est

	* Establishment controlls without tenure + bp
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg, fe vce(robust)
	estimates store base_ot_est_bp
	
	* Establishment controlls without tenure + bp
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg $job_hist, fe vce(robust)
	estimates store base_ot_est_bp_jobhist	 


	estimates table base  base_est base_ot_est ///
					base_ot_est_bp,  b(%7.4f) star stats(N r2 F)
	esttab base base_est base_ot_est ///
			base_ot_est_bp using "${results}\wage-growth-resub-stayer-and-mover.csv",  ///
			nonumber title("Models for full sample") ///
			mtitle("all" "all_est" "all_ot_est" ///
			 "all_ot_est_bp") ///
			star(* 0.10 ** 0.05 *** 0.01) stats(N r2 F)  scsv replace

			
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg, fe vce(robust)
	estimates store all
	
	/// sex
	tab sex
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg if sex==1, fe vce(robust)
	estimates store sex1

	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg if sex==2, fe vce(robust)
	estimates store sex2
	
	/// educ
	tab educ,m
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg if educ==1, fe vce(robust)
	estimates store educ1

	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg if educ==2, fe vce(robust)
	estimates store educ2
	
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg if educ==3, fe vce(robust)
	estimates store educ3
	
	estimates table all sex1 sex2 ///
					educ1 educ2 educ3,  b(%7.4f) star stats(N r2 F)
	esttab all sex1 sex2 ///
			educ1 educ2 educ3 using "${results}\wage-growth-resub-all-sex-educ.csv",  ///
			nonumber title("Models for full sample") ///
			mtitle("all" "sex1" "sex2" "educ1" "educ2" "educ3" ///
			 "all_ot_est_bp") ///
			star(* 0.10 ** 0.05 *** 0.01) stats(N r2 F)  scsv replace
	
	/// sector
	global timereg2 agesq lnes lnessq dtox_1_5 dtox_2_5 Dtask_1-Dtask_4 Dagg_bula_2-Dagg_bula_4 DRtyp_2-DRtyp_4		//time-varying variables without tenure
	tab IND,m
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg if IND==1, fe vce(robust)
	estimates store IND1
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg if IND==2, fe vce(robust)
	estimates store IND2
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg if IND==3, fe vce(robust)
	estimates store IND3
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg if IND==4, fe vce(robust)
	estimates store IND4
	xtreg  lnwdir DT3_2_16 DT3_3_16 dy* $timereg2 $eshreg $bpreg if IND==5, fe vce(robust)
	estimates store IND5
	
	estimates table IND1 IND2 IND3 IND4 IND5,  b(%7.4f) star stats(N r2 F)
	esttab IND1 IND2 IND3 IND4 IND5 using "${results}\wage-growth-resub-all-IND.csv",  ///
			nonumber title("Models for full sample") ///
			mtitle("IND1" "IND2" "IND3" "IND4" "IND5"  ///
			 "all_ot_est_bp") ///
			star(* 0.10 ** 0.05 *** 0.01) stats(N r2 F)  scsv replace


log close
exit		


